%bcond docs 1

Name:           libipuz
Version:        0.5.0
Release:        1.20250107040843711197.master.585.g6706bff%{?dist}
Summary:        Library for parsing .ipuz puzzle files

License:        LGPL-2.1-or-later OR MIT
URL:            https://gitlab.gnome.org/jrb/libipuz
Source:         libipuz-0.5.0.tar.gz

# Ensure we only enable introspection support from 0.4.7 onwards
%bcond introspection %([ $(echo %{version} | tr -d .) -eq 047 ] && echo 1 || echo 0)

BuildRequires:  cargo-rpm-macros >= 24
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  meson
BuildRequires:  python3
BuildRequires:  sed
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(myst-parser)
%endif

BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
%if %{with introspection}
BuildRequires:  gi-docgen
BuildRequires:  gobject-introspection-devel
%endif

%description
This is a library for parsing .ipuz puzzle files, for crossword puzzles,
sudokus, etc. The library only handles crosswords for now.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with docs}
Suggests:       %{name}-doc = %{version}-%{release}
%endif

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if %{with docs}
%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
This package contains additional documentation for %{name}.
%endif

%package        tests
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    tests
The %{name}-tests package contains tests for %{name}.

%prep
%autosetup -p1 -n libipuz-0.5.0
%cargo_prep

# Drop version locks
rm libipuz/rust/Cargo.lock
sed -i '/Cargo.lock/d' libipuz/rust/meson.build

%generate_buildrequires
cd libipuz/rust
%cargo_generate_buildrequires

%build
%meson
%meson_build

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%meson_install

%check
%meson_test

%files
%license LICENSE COPYING.LGPL COPYING.MIT
%doc README.md NEWS.md
%{_libdir}/lib%{name}-0.4.so

%files devel
%{_includedir}/*
%if %{with introspection}
%{_datadir}/gir-1.0/Ipuz-1.0.gir
%{_libdir}/girepository-1.0/Ipuz-1.0.typelib
%endif
%{_libdir}/pkgconfig/%{name}-0.4.pc

%if %{with docs}
%files doc
%license LICENSE COPYING.LGPL COPYING.MIT
%doc html
%if %{with introspection}
%doc %{_docdir}/%{name}-1.0/
%endif
%endif

%files tests
%dir %{_datadir}/installed-tests
%{_datadir}/installed-tests/%{name}-1.0
%dir %{_libexecdir}/installed-tests
%{_libexecdir}/installed-tests/%{name}-1.0

%changelog
* Tue Jan 07 2025 Packit <hello@packit.dev> - 0.5.0-1.20250107040843711197.master.585.g6706bff
- Minor text cleanup to README (Jonathan Blandford)
- Add a link to the gobject introspection languages (Jonathan Blandford)
- Update main page (Jonathan Blandford)
- Bump version (Jonathan Blandford)
- Update NEWS (Jonathan Blandford)
- Add annotations and documentation to IpuzCellCoord (Jonathan Blandford)
- ipuz_clue_get_coords now takes a const clue (Jonathan Blandford)
- Initializ cell_type to be NORMAL for guesses. (Jonathan Blandford)
- nonogram: Set a default block style for monochrome nonos (Jonathan Blandford)
- fixes (Philip Chimento)
- crossword: Move set_style implementation to IpuzGrid (Philip Chimento)
- Initializ cell_type to be NORMAL for guesses. (Jonathan Blandford)
- Untested change to set a block style for monochrome nonos (Jonathan Blandford)
- Fix some silly bugs (Jonathan Blandford)
- Add a separate call to check_cell for color nonograms (Jonathan Blandford)
- Update documentation (Jonathan Blandford)
- Finish rename of `self` to `clues` for the IpuzClues `this` variable (Jonathan Blandford)
- Add setters for IpuzClues (Jonathan Blandford)
- Update docs for remove_clue (Jonathan Blandford)
- Change unlink_clue to remove_clue (Jonathan Blandford)
- Update docs. First draft finished (Jonathan Blandford)
- Add an additional warning about switch() to IpuzClueDirection (Jonathan Blandford)
- change 'self' argument to be clues instead (Jonathan Blandford)
- migrate docs to separate docs file and stub it out (Jonathan Blandford)
- Require a grid and not a puzzle for Clues (Jonathan Blandford)
- Update docs (Jonathan Blandford)
- More editing of the intro. (Jonathan Blandford)
- Annotate get_clue_by_id() with transfer none (Jonathan Blandford)
- Update planned inheritance tree and add a Grid column (Jonathan Blandford)
- Text cleanups (Jonathan Blandford)
- Make it clear there are API docs (Jonathan Blandford)
- Add a test for the intro example (Jonathan Blandford)
- Clean up the intro (Jonathan Blandford)
- Add examples for ipuz-cell (Jonathan Blandford)
- additional docs written (Jonathan Blandford)
- Remove docs from the c file (Jonathan Blandford)
- Change the intro of each struct's docs to follow the same pattern (Jonathan Blandford)
- Add stubs for the rest of the documentation (Jonathan Blandford)
- Add a note about the lack of checking in IpuzCell (Jonathan Blandford)
- Reformat list (Jonathan Blandford)
- Make structure of IpuzCell private (Jonathan Blandford)
- Migrate clone to public API (Jonathan Blandford)
- Remove comment marking set_clue as private (Jonathan Blandford)
- Add a function to get the raw array of clues (Jonathan Blandford)
- Add a dispose method to ipuz-grid (Jonathan Blandford)
- Use public functions to clone the cell (Jonathan Blandford)
- Reindent header (Jonathan Blandford)
- Reorder header (Jonathan Blandford)
- remove ipuz_cell_dup() (Jonathan Blandford)
- Move private functions to the end of the puzzle (Jonathan Blandford)
- Make ipuz_cell_new() private (Jonathan Blandford)
- Initial docs for cells (Jonathan Blandford)
- Use public getters/setters for IpuzCell (Jonathan Blandford)
- Change IPUZ_CELL calls to use functions instead of direct member access (Jonathan Blandford)
- Add ipuz_cell_[gs]et_name (Jonathan Blandford)
- use g_ascii_strcasecmp instead of g_strcmp (Jonathan Blandford)
- fix leak in test (Jonathan Blandford)
- Add docs for the rest of the methods (Jonathan Blandford)
- Cleanups (Jonathan Blandford)
- clean up header (Jonathan Blandford)
- Make the json code for IpuzClue private (Jonathan Blandford)
- Minor doc fixes (Jonathan Blandford)
- Allow a NULLable location to unset the location (Jonathan Blandford)
- Update get_first_coord() to match the rest of the API (Jonathan Blandford)
- Initial docs for IpuzClue (Jonathan Blandford)
- update headers to match functions (Jonathan Blandford)
- Make argument more verbose. (Jonathan Blandford)
- Change toggle of the diagonals to make more sense (Jonathan Blandford)
- Change parameters to match the rest of the library (Jonathan Blandford)
- Change IpuzClue API naming to coords instead of cells (Jonathan Blandford)
- Move documentation into doc comment (Jonathan Blandford)
- test IpuzCellCoordArray::clear function (Jonathan Blandford)
- add a clear function to IpuzCellCoordArray (Jonathan Blandford)
- Fix issues with cargo build type (Adam Fontenot)
- ipuz_clue_get_enumeration() doesn't transfer full (Jonathan Blandford)
- Hide IpuzClue struct (Jonathan Blandford)
- Make IpuzClue accessors take a const self (Jonathan Blandford)
- consolidate ipuz_clue_direction functions (Jonathan Blandford)
- use accessors for IpuzClue (Jonathan Blandford)
- ake it more clear that certain arrays are const (Jonathan Blandford)
- cleanup header (Jonathan Blandford)
- ipuz_clue_set/get_location matches the rest of the API (Jonathan Blandford)
- convert clue->coords to an IpuzCellCoordArray (Jonathan Blandford)
- Avoid a deadlock when array1 == array2 (Jonathan Blandford)
- Port from get_cells → get_n_coords() et al. (Jonathan Blandford)
- Add ipuz_cell_coord_array_equal() (Jonathan Blandford)
- Change clue->cells to clue->coords and make it private (Jonathan Blandford)
- Add an API to get the coords from the clue (Jonathan Blandford)
- Move ipuz-cell-coord to its own file (Jonathan Blandford)
- Test new memory managment (Jonathan Blandford)
- Fix up the copy/free mess in IpuzCharsetBuilder (Jonathan Blandford)
- Change ipuz_charset_compare to ipuz_charset_equal (Jonathan Blandford)
- Fix docs (Jonathan Blandford)
- Initial docs for CharsetBuilder (Jonathan Blandford)
- fix memleak in example code (Jonathan Blandford)
- Add the examples from IpuzCharset to the tests (Jonathan Blandford)
- Finish documenting IpuzCharset (Jonathan Blandford)
- s/ipuz_charset_get_size/ipuz_charset_get_total_count/g (Jonathan Blandford)
- Write a section header for charsets (Jonathan Blandford)
- Add ipuz_charset_builder_remove_character back (Jonathan Blandford)
- Quick pass of docs (Jonathan Blandford)
- s/Iter/Value (Jonathan Blandford)
- dynamically allocate the value to test that as well (Jonathan Blandford)
- Pull the const definition of LANGUAGES to the top of the file. (Jonathan Blandford)
- Fix wrong function name in g_return macro (Jonathan Blandford)
- Provide definitions for CharsetValue::free/new (Jonathan Blandford)
- remove unused #define of alphabets (Jonathan Blandford)
- Change get_value to take an in-property (Jonathan Blandford)
- Add macros for IpuzCharsetBuilder (Jonathan Blandford)
- remove ipuz_crossword_game_won (Jonathan Blandford)
- Write ipuz_puzzle_game_won (Jonathan Blandford)
- fix check_cell (Jonathan Blandford)
- Remove has_solution from IpuzCrosswords (Jonathan Blandford)
- Include has_solution when cloning a grid (Jonathan Blandford)
- Clean up crosswords header (Jonathan Blandford)
- delete ipuz_crossword_find_clue_by_* (Jonathan Blandford)
- remove unused ipuz_crossword_get_width/height (Jonathan Blandford)
- remove ipuz_crossword_clue_guessed (Jonathan Blandford)
- remove ipuz_crossword_get_clue/guess_string_by_id (Jonathan Blandford)
- remove ipuz_crossword_get_id_by_clue (Jonathan Blandford)
- remove ipuz_crossword_unlink_clue (Jonathan Blandford)
- remove ipuz_clues_get_clue_by_id (Jonathan Blandford)
- remove ipuz_crossword_get_n_clues (Jonathan Blandford)
- remove ipuz_crossword_foreach_clue (Jonathan Blandford)
- remove ipuz_crossword_get_clues (Jonathan Blandford)
- remove ipuz_crossword_clue_set_get_label (Jonathan Blandford)
- remove ipuz_clues_clue_set_get_dir (Jonathan Blandford)
- remove ipuz_crossword_get_n_clue_sets (Jonathan Blandford)
- Add ipuz-clues to libipuz.h (Jonathan Blandford)
- migrate the find_clue_by() functions (Jonathan Blandford)
- Remove ipuz_crossword_find_clues (Jonathan Blandford)
- migrate clue_guessed (Jonathan Blandford)
- Add a new grid check type: GUESS_MADE (Jonathan Blandford)
- Migrate get_string_by_id functions (Jonathan Blandford)
- migrate get_id_by_clue (Jonathan Blandford)
- Update image to include labels (Jonathan Blandford)
- Test examples in the docs (Jonathan Blandford)
- Migrate unlink_clue (Jonathan Blandford)
- Migrate get_clue_by_id (Jonathan Blandford)
- migrate get_n_clues (Jonathan Blandford)
- migrate get_clues (Jonathan Blandford)
- migrate foreach_clue (Jonathan Blandford)
- change polarity of check for clue_sets (Jonathan Blandford)
- Remove ipuz_crossword_get_clue_sets (Jonathan Blandford)
- Migrate the clue_set methods of IpuzClues (Jonathan Blandford)
- Move get_n_clue_sets to ipuz_clues (Jonathan Blandford)
- Set the IpuzPuzzle clue_sets field (Jonathan Blandford)
- Move the private get_clue_sets function down to ipuz_crossword (Jonathan Blandford)
- Add interface (Jonathan Blandford)
- Fix typo in get_type() definition (Jonathan Blandford)
- Initial public functions for IpuzClues (Jonathan Blandford)
- Initial header for ipuz clues (Jonathan Blandford)
- ipuz-clue-sets is now a private header (Jonathan Blandford)
- Fix leak in sync_grid_to_quote (Jonathan Blandford)
- Truncate the normalized string if it's too long (Jonathan Blandford)
- Update docs (Jonathan Blandford)
- Add docs for IPUZ_ACROSTIC_MAX_QUOTE_STR_LENGTH (Jonathan Blandford)
- Change fix_source() to match the docs (Jonathan Blandford)
- new function: ipuz_clue_sets_remove_set (Jonathan Blandford)
- Update the docs completely (Jonathan Blandford)
- go through the public set_quote function rather than duplicating it. (Jonathan Blandford)
- Update the normalized quote after syncing from the grid (Jonathan Blandford)
- Restrict IpuzPuzzle:block to one unicode char (Jonathan Blandford)
- Fix the sync to/from quote functions (Jonathan Blandford)
- Normalize the source (Jonathan Blandford)
- Use 'block' in normalized string to indicate a break, rather than ' ' (Jonathan Blandford)
- Add a test of a completely invalid quote (Jonathan Blandford)
- Support a 0,0 board (Jonathan Blandford)
- Update tests to match current code. Everything passes now (Jonathan Blandford)
- Rewrite normalize quote function to match docs (Jonathan Blandford)
- we don't need to get source from g_object (Jonathan Blandford)
- Style and comment fixups (Jonathan Blandford)
- free normalized strings (Jonathan Blandford)
- Store normalized copies of the quote and source string (Jonathan Blandford)
- Add a test for the dupe behavior (Jonathan Blandford)
- Make sure we dup the quote and source strings in ::clone() (Jonathan Blandford)
- rename to find_quote_clue_in_clues (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Update docs (Jonathan Blandford)
- Change fix_source to get a direction (Jonathan Blandford)
- Update images (Jonathan Blandford)
- Change QUOTE_STR_TO_GRID to STRING_TO_PUZZLE (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- update docs (Jonathan Blandford)
- Initial docs (Jonathan Blandford)
- Add an example acrostic image (Jonathan Blandford)
- Change polarity of g_return_val_if_fail() (Jonathan Blandford)
- Update docs to include a section on nonograms (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Fix leaks (Tanmay Patil)
- crossword-to-grid updates (Tanmay Patil)
- Improve tests and add a doc comment (Tanmay Patil)
- Test warnings (Tanmay Patil)
- crossword-to-grid updates (Tanmay Patil)
- Fix indentation (Tanmay Patil)
- CharsetBuilder: rename *_free() to *_unref() (Tanmay Patil)
- Add inline docs (Tanmay Patil)
- Add tests for ipuz_charset_build_remove_character (Tanmay Patil)
- charset: Add ipuz_charset_builder_remove_character (Tanmay Patil)
- The checksum of an empty grid isn't NULL (Jonathan Blandford)
- Include the guesses when cloning a puzzle. (Jonathan Blandford)
- remove spurious return (Jonathan Blandford)
- change polarity of check_cell() (Jonathan Blandford)
- Massive change (Jonathan Blandford)
- Fix documentation markup (Jonathan Blandford)
- Update docs (Jonathan Blandford)
- Needed for tests (Jonathan Blandford)
- move the code to fix up cells on a clone to crossword (Jonathan Blandford)
- Fix typo in comment (Jonathan Blandford)
- Add a test for create_from_grid (Jonathan Blandford)
- Resize the rows to the right value (Jonathan Blandford)
- Changed back the behavior of ipuz_grid_create_guesses() (Jonathan Blandford)
- Update the docs for check_cell() (Jonathan Blandford)
- Remove dead code (Jonathan Blandford)
- Pass the guesses to ipuz_grid_check_cell() (Jonathan Blandford)
- Add tests for invalid answers (Tanmay Patil)
- Change ipuz_acrostic_set_answers to return a boolean (Tanmay Patil)
- Validate answers, check whether all cells are getting mapped (Tanmay Patil)
- Handle exceptions (Tanmay Patil)
- remove commented out builder functions (Jonathan Blandford)
- Delete ipuz-board (Jonathan Blandford)
- Remove IpuzBoard from use in the code (Jonathan Blandford)
- Add a guard against memcmp (NULL, NULL, 0); (Jonathan Blandford)
- Move get_cell_by_clue into ipuz-crossword (Jonathan Blandford)
- Add annotation to indicate ownership of guesses (Jonathan Blandford)
- Forgot the obvious ref count (Jonathan Blandford)
- Change ipuz_grid_create_guesses to set the guesses on grid (Jonathan Blandford)
- Add a check_cell function to crossword (Jonathan Blandford)
- remove priv->width/height (Jonathan Blandford)
- Refactor to make more legible (Jonathan Blandford)
- get the priv of the src, not the dest (Jonathan Blandford)
- First pass at removing board (Jonathan Blandford)
- Remove the board  property (Jonathan Blandford)
- Move from ipuz_board_equal to ipuz_puzzle_equal() (Jonathan Blandford)
- Add missing (transfer none) to ipuz_puzzle_get_style (Philip Chimento)
- Clean up docs (Jonathan Blandford)
- Fix leak (Tanmay Patil)
- IpuzPuzzle ensures default EN charset (Tanmay Patil)
- acrostic: use charset from IpuzPuzzle (Tanmay Patil)
- Load source from file (Tanmay Patil)
- Assign labels to cells in a separate fix_labels() function (Tanmay Patil)
- Change return type of ipuz_nonogram_get_group() to const (Philip Chimento)
- Test the right thing with clue group. (Jonathan Blandford)
- Print the color with the clue count (Jonathan Blandford)
- Copy the correct solution to group (Jonathan Blandford)
- Inherit from IpuzGrid (Jonathan Blandford)
- Fix NONOGRAM COLOR docs (Jonathan Blandford)
- Fix NONOGRAM COLOR docs (Jonathan Blandford)
- Pass in the version string when creating new puzzles (Jonathan Blandford)
- Fix documentation for IPUZ_PUZZLE_KIND (Jonathan Blandford)
- Remove duplicated get/set property prototypes (Jonathan Blandford)
- This was unused. Deleted (Jonathan Blandford)
- Update docs to reflect removal of IPUZ_NONOGRAM_BLOCKS (Jonathan Blandford)
- Remove IPUZ_NONOGRAM_BLOCK (Jonathan Blandford)
- Update documentation (Jonathan Blandford)
- Test the cell style (Jonathan Blandford)
- Fix the styles of cells after a change (Jonathan Blandford)
- Pass in a stringptr function to qsort (Jonathan Blandford)
- Fix another leak. (Jonathan Blandford)
- plug leak in the clue_array (Jonathan Blandford)
- Update nonogram documentation (Jonathan Blandford)
- Minor style fix (Jonathan Blandford)
- Add documentation for IPUZ_NONOGRAM_BLOCK (Jonathan Blandford)
- Remove these docs in favor of the -docs docs (Jonathan Blandford)
- Add more tests (Jonathan Blandford)
- Three new functions to inspect groups (Jonathan Blandford)
- sort the groups (Jonathan Blandford)
- Calculate the number of colors, as well as each cell per color (Jonathan Blandford)
- Use a #define for "#" character (Jonathan Blandford)
- add a test for color nonograms (Jonathan Blandford)
- Correctly load the clues (Jonathan Blandford)
- Print out the block groups (Jonathan Blandford)
- Pass the actual kind in to parse_puzzle() (Jonathan Blandford)
- Pass the kind into parse_puzzle_value (Jonathan Blandford)
- Parse the nonogram color kind correctly (Jonathan Blandford)
- Pass the correct kind to ipuz_cell_parse* (Jonathan Blandford)
- Pass the kind in to ipuz_cell_parse_* (Jonathan Blandford)
- Add documentation (Jonathan Blandford)
- Add comment (Jonathan Blandford)
- Adjust the clue generation to allow for colors (Jonathan Blandford)
- Remove get_clue_group_style () (Jonathan Blandford)
- Include ipuz-nonogram-color.h with libipuz.h (Jonathan Blandford)
- Create a color nonogram puzzle from the kind string (Jonathan Blandford)
- Add a kind string for IPUZ_PUZZLE_NONOGRAM_COLOR (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Remove libipuz/libipuz.h from #inclues (Jonathan Blandford)
- Change the kind string to be /colornonogram instead of just /color (Jonathan Blandford)
- Change IpuzNonogramClue to include a string for the group (Jonathan Blandford)
- Make the defintion of normal less puzzle-specific (Jonathan Blandford)
- Update the test files to match the updated format (Jonathan Blandford)
- Add IpuzNonogramColor (Jonathan Blandford)
- Split documentation between IpuzNonogram and IpuzNonogramColor (Jonathan Blandford)
- Clarify that guesses are defined per class (Jonathan Blandford)
- Add some brief documentation for the new format. (Jonathan Blandford)
- Document the new representation of nonograms (Jonathan Blandford)
- validate the clues and call g_warning(), if they are invalid (Tanmay Patil)
- Add cell argument to check_cell (Jonathan Blandford)
- Add ipuz_grid_fix_guesses() (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Add docs for resize (Jonathan Blandford)
- Add create_guesses() (Jonathan Blandford)
- Implement INITIALIZE_GUESSES in nonogram (Jonathan Blandford)
- Add a new operation to check_cell (Jonathan Blandford)
- Fix typo (Jonathan Blandford)
- Add a fourth option (Jonathan Blandford)
- Match order of enum (Jonathan Blandford)
- Add GUESSABLE to nonogram::check_cell (Jonathan Blandford)
- Change enum to match remainder of the enum types (Jonathan Blandford)
- Add documentation for check_cell (Jonathan Blandford)
- Refactor (Tanmay Patil)
- Rename function (Tanmay Patil)
- Change the calling order of check_cell (Jonathan Blandford)
- Use G_N_ELEMENTS instead of hardcoding 26 (Tanmay Patil)
- Add tests around an empty guesses (Jonathan Blandford)
- Return NULL when a 0x0 checksum is passed in (Jonathan Blandford)
- Add a test case for guesses (Jonathan Blandford)
- add ipuz_guesses_resize() (Jonathan Blandford)
- Add ipuz_guesses_new () (Jonathan Blandford)
- rust/charset: remove IpuzCharsetIter and use indexing (Pranjal Kole)
- Use check-cell to make sure we have valid guesses (Jonathan Blandford)
- Add a check_cell() internal function (Jonathan Blandford)
- Add fixmes to the crossword-specific part of IpuzGrid (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- add set_guesses and get_guesses (Jonathan Blandford)
- Store the guesses with IpuzGrid (Jonathan Blandford)
- Add a stub for fix_guesses() (Jonathan Blandford)
- Proposed example nonogram color file (Jonathan Blandford)
- Update docs for IpuzGuesses (Jonathan Blandford)
- Add a section on the solution overlay (Jonathan Blandford)
- Make header levels and strings consistent (Jonathan Blandford)
- Remove check on cell_type when writing a guess (Jonathan Blandford)
- Style and wording improvements (Jonathan Blandford)
- Test ipuz_guesses_set_cell_type() (Jonathan Blandford)
- Add set_cell_type() to IpuzGuesses (Jonathan Blandford)
- Change title to be more accurate (Jonathan Blandford)
- Add section about initial val (Jonathan Blandford)
- C markup (Jonathan Blandford)
- admonitions don't work with glfm (Jonathan Blandford)
- Fix filename (Jonathan Blandford)
- Update to include the API proposal (Jonathan Blandford)
- Initial thoughts on hte nonogram format (Jonathan Blandford)
- Fix leak in clearing the down clues (Jonathan Blandford)
- test ipuz_nonogram_get_clues (Jonathan Blandford)
- Implement and document ipuz_nonogram_get_clues (Jonathan Blandford)
- Fill out the print function (Jonathan Blandford)
- s/horizontal/across/g (Jonathan Blandford)
- WIP: nonograms calculate their clues correctly with the initial test (Jonathan Blandford)
- Create the horizontal and vertical clues (Jonathan Blandford)
- remove fixup_cells and equal (Jonathan Blandford)
- Add ipuz_grid_foreach_cell (Jonathan Blandford)
- Clean up docs (Jonathan Blandford)
- Move the style fixup to IpuzGrid (Jonathan Blandford)
- Drive by documentation for IpuzClueId (Jonathan Blandford)
- These are unneeded with the transition to IpuzGrid (Jonathan Blandford)
- Initial attempt at a clone function (Jonathan Blandford)
- Cast puzzle to a grid (Jonathan Blandford)
- Move the get_flags flags to IpuzGrid (Jonathan Blandford)
- remove clone as well (Jonathan Blandford)
- We don't need load and post_load at this time. (Jonathan Blandford)
- Start writing docs and setting annotations (Jonathan Blandford)
- Migrate from IpuzPuzzle to IpuzGrid (Jonathan Blandford)
- More IpuzGrid work (Jonathan Blandford)
- Initial cut at an IpuzGrid parent class (Jonathan Blandford)
- Build the docs as well (Jonathan Blandford)
- include ipuz-nonogram-clue in the libipuz.h (Jonathan Blandford)
- include full ipuz headers (Jonathan Blandford)
- Add IpuzNonogramClue and associated docs (Jonathan Blandford)
- Use the new logo in the docs (Jonathan Blandford)
- Add a thumb for logo2 (Jonathan Blandford)
- Start thinking of what a nonogram with a solution could look like (Jonathan Blandford)
- Add a test file. Currently just makes sure it loads (Jonathan Blandford)
- Add a little info on build (Jonathan Blandford)
- More work on IpuzNonogram (Jonathan Blandford)
- Initial test nonogram file (Jonathan Blandford)
- Initial nonogram class (Jonathan Blandford)
- Make the main page logo use a thumbnail instead (Jonathan Blandford)
- Add the second logo (Jonathan Blandford)
- Add a logo (Jonathan Blandford)
- Overwrite IpuzCrossword fix_clues method (Tanmay Patil)
- Move get_clue_sets() declaration to ipuz-private.h (Tanmay Patil)
- Add doc clarification to ipuz_guesses_get_percent (Jonathan Blandford)
- s/self/guesses (Jonathan Blandford)
- Make text consistent with the rest of the documentation (Jonathan Blandford)
- Change old-style class doc reference with the new style (Jonathan Blandford)
- Add missing (transfer full) annotation (Jonathan Blandford)
- Fill out the IpuzGuesses docs (Jonathan Blandford)
- Change function signatures to new coding style (Jonathan Blandford)
- Make test dup_boxed instead of get_boxed (Jonathan Blandford)
- count_bytes() is still experimental. Use is_empty() instead (Jonathan Blandford)
- Make sure we include all the rust files (Jonathan Blandford)
- Clean up for loop (Jonathan Blandford)
- This function's signature is a float, not a double (Jonathan Blandford)
- Allow NULL to/from ipuz_guesses_[gs]et_guess() (Jonathan Blandford)
- Allow non_snake_case and non_camel_case for matching C variables (Jonathan Blandford)
- Replace the very rough ascii art with an image (Jonathan Blandford)
- Require a newer gidocgen version (Jonathan Blandford)
- add an image for IpuzEnumerationForeachDelimFunc (Jonathan Blandford)
- More tests for clue label assignments (Tanmay Patil)
- Add tests for clue label assignment (Tanmay Patil)
- Dynamically generate labels for clues based on their index (Tanmay Patil)
- Test whether cells are getting mapped correctly (Tanmay Patil)
- This is a callback, not a func (Jonathan Blandford)
- Add an explicit link to the documentation (Jonathan Blandford)
- Set clue direction to CLUES instead of ZONES (Tanmay Patil)
- Add enumeration docs (Jonathan Blandford)
- Add an image of enumerations to the docs (Jonathan Blandford)
- Add additional test for set_answers() (Tanmay Patil)
- rust/charset: change Charset to SharedBoxed (Pranjal Kole)
- rust/charset: implement copy/free for CharsetBuilder (Pranjal Kole)
- rust/enumeration: remove Mutex<T> (Pranjal Kole)
- rust/guesses: change from Boxed to SharedBoxed (Pranjal Kole)
- rust/ffi: add type alias for grefcount (Pranjal Kole)
- guesses: add error_quark (Pranjal Kole)
- libipuz/docs: add ipuz-guesses-docs (Pranjal Kole)
- guesses: port to rust (Pranjal Kole)
- Split code into smaller functions (Tanmay Patil)
- Fix obvious memory leaks (Tanmay Patil)
- This was done to check saved file locally (Tanmay Patil)
- Acrostic: Map cell label to it's clue cell (Tanmay Patil)
- Fix memory leaks (Tanmay Patil)
- Fix memory leak (Tanmay Patil)
- Fix: append the coord after creating the array (Tanmay Patil)
- WIP: Set acrostic answers (Tanmay Patil)
- rust/enumeration: change from Boxed to SharedBoxed (Pranjal Kole)
- remove stray '*' in function prototype (Jonathan Blandford)
- Add missing ipuz_cell_coord_free() (Jonathan Blandford)
- cell-array:implemented C API for IPuzCoordArray (Shruti  Sharma)
- Remove the clue_sets_duplicates test. (Jonathan Blandford)
- Fix typo in docs (Jonathan Blandford)
- Clarify comment (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Hide some fields we don't use (Jonathan Blandford)
- Try an additional indent to see if admonitions can work correctly (Jonathan Blandford)
- Update intro description (Jonathan Blandford)
- let style_name be nullable (Jonathan Blandford)
- Fix mistake in text (Jonathan Blandford)
- include style docs (Jonathan Blandford)
- Clean up header (Jonathan Blandford)
- fix broken doc text (Jonathan Blandford)
- Add section header to IpuzStyle (Jonathan Blandford)
- Add params to example (Jonathan Blandford)
- Add enums to IpuzStyle (Jonathan Blandford)
- Update meson.build to replace deprecated features (Tanmay Patil)
- Missed two more cut-and-paste errors (Jonathan Blandford)
- Copied the default to the wrong string (Jonathan Blandford)
- Finished documenting IPuzPuzzle (Jonathan Blandford)
- Removed all instances of "@self: An #IpuzPuzzle" (Jonathan Blandford)
- Mark the whole struct as private. Nothing here should be exported (Jonathan Blandford)
- fix a typo (Jonathan Blandford)
- Add a section header for IpuzPuzzle (Jonathan Blandford)
- version should be readwrite, but construct only (Jonathan Blandford)
- Fix IPUZ_PUZZLE_ERROR quark (Jonathan Blandford)
- Quick side-quest to document IpuzPuzzleInfo (Jonathan Blandford)
- More documentation for IpuzPuzzle (Jonathan Blandford)
- Finish the annotations/documentation for the IpuzPuzzle properties (Jonathan Blandford)
- Seven more properties documented (Jonathan Blandford)
- Use org.libipuz namespace to declare "source" extension to ipuz (Tanmay Patil)
- Store the source string in .ipuz file (Tanmay Patil)
- Document the copyright and publisher properties fully (Jonathan Blandford)
- More work on documentation (Jonathan Blandford)
- Add getters/setters for most object properties (Jonathan Blandford)
- Fix memory leak (Tanmay Patil)
- Resolve rebase conflicts (Tanmay Patil)
- Add ipuz_acrostic_fix_source (Tanmay Patil)
- Update doc comments (Tanmay Patil)
- Refactor: replace all instances of *_str or *-string with only 'quote'/'source' (Tanmay Patil)
- Add source_str as a property to IPuzAcrostic (Tanmay Patil)
- fix comment typo (Jonathan Blandford)
- Make styles READABLE only for now (Jonathan Blandford)
- s/get_info/get_puzzle_info/ (Jonathan Blandford)
- Make ipuz_arrowword_foreach_blocks() consistent (Jonathan Blandford)
- Document IpuzCrosswordForeachClueFunc (Jonathan Blandford)
- Make IpuzPuzzleStyleForeach consistent (Jonathan Blandford)
- clean up enumeration text (Jonathan Blandford)
- Get the document reference right (Jonathan Blandford)
- Fix up the documentation (Jonathan Blandford)
- Actually make IpuzEnumerationForeachDelimFunc consistent (Jonathan Blandford)
- Make IpuzStyleForeachMarkFunc consistent with the rest (Jonathan Blandford)
- Remove debug print statements (Jonathan Blandford)
- Add doc comments to IpuzEnumerationForeachDelimFunc (Jonathan Blandford)
- Make IpuzEnumerationForeachDelimFunc consistant (Jonathan Blandford)
- Change CellCellType to CellType in the docs (Jonathan Blandford)
- Document IpuzCellType (Jonathan Blandford)
- Change IpuzCellCellType to just IpuzCellType (Jonathan Blandford)
- No longer safe to allocate IpuzCell's on the stack (Jonathan Blandford)
- Update the python example in the docs to work (Jonathan Blandford)
- Add transfer none to make get_clue_by_id() work (Jonathan Blandford)
- Add docs/annotations to get_cell() (Jonathan Blandford)
- Migrate cells to be ref counted. (Jonathan Blandford)
- Change IpuzClue from copy to refcounting (Jonathan Blandford)
- update libipuz page (Jonathan Blandford)
- Try and add a dependency on the build (Jonathan Blandford)
- Now let's try and include the reference correctly (Jonathan Blandford)
- Change gen-reference to be plausibly correct (Jonathan Blandford)
- Bump the BASE tag (Jonathan Blandford)
- Try manually including gi-docgen (Jonathan Blandford)
- Add a ref count (Jonathan Blandford)
- Add more dependencies (Jonathan Blandford)
- Include python deps for gi-gendoc (Jonathan Blandford)
- remove need of build (Jonathan Blandford)
- Missing a closed quote (Jonathan Blandford)
- Try to build and export the devel docs (Jonathan Blandford)
- Add docs/annotations to get_cell() (Jonathan Blandford)
- Set up a stub of an intro file (Jonathan Blandford)
- Add const to all the IpuzCellCoords passed in (Jonathan Blandford)
- Add doc comment to ipuz_symmetry_calculate (Jonathan Blandford)
- Change symmetry code to pass the coords by reference (Jonathan Blandford)
- Change IpuzArrowword to pass the coord by ref (Jonathan Blandford)
- Change IpuzGuesses to pass the coord by ref (Jonathan Blandford)
- Change IpuzBoard to pass coord by ref insted of by value (Jonathan Blandford)
- Change IpuzCellCoord args from value-> reference (Jonathan Blandford)
- Move from IpuzClueIds to pass by reference (Jonathan Blandford)
- remove proto for get_offset_coord() (Jonathan Blandford)
- Change get_clue_id to get_id_by_clue (Jonathan Blandford)
- Chain up to the parent class in finalize (Jonathan Blandford)
- Update the fedora requirements (Jonathan Blandford)
- merge the two meson options files (Jonathan Blandford)
- Add documentation for set_size (Jonathan Blandford)
- document IpuzCellCoord (Jonathan Blandford)
- Be quiet, git (Jonathan Blandford)
- removed unused attribute (Jonathan Blandford)
- Add gi-docgen support (Jonathan Blandford)
- Remove deprecated use of build_root() (Jonathan Blandford)
- Make IpuzCharsetBuilder a boxed type and ref counted (Jonathan Blandford)
- Add annotations for gobject-introspection (Jonathan Blandford)
- Add annotations for gobject-introspection (Jonathan Blandford)
- Mark ipuz_puzzle_info_get_unches() as unimplemented (Jonathan Blandford)
- Make IpuzCellStats a boxed type (Jonathan Blandford)
- temporarily annotate get_cells() (Jonathan Blandford)
- Add scope annotation for foreach() (Jonathan Blandford)
- add libubsan explicitly (Jonathan Blandford)
- remove unused quote_str (Jonathan Blandford)
- Use the docs files with gobject-introspection (Jonathan Blandford)
- Initial version of enumeration docs (Jonathan Blandford)
- Split charset into the docs and the header file (Jonathan Blandford)
- Change enumeration to @self to make it more consistent (Jonathan Blandford)
- Add meson_options file (Jonathan Blandford)
- The interesting thing about this file is the docs, not the stubs (Jonathan Blandford)
- New plan: separate docs from headers (Jonathan Blandford)
- Set back ipuz-charset.h file (Jonathan Blandford)
- Copy ipuz-charset.h into stub/ipuz-charset-stub.c (Jonathan Blandford)
- Keep ipuz-charset.h (Jonathan Blandford)
- Include json-glib with our dependencies (Jonathan Blandford)
- Prepare for gobject-introspection (Jonathan Blandford)
- IpuzCharset: clean up doc comments and annotations (Jonathan Blandford)
- Register IpuzCharset as a boxed type (Jonathan Blandford)
- Derive from the glib::Enum type (Jonathan Blandford)
- Enumeration in rust represents IpuzEnumeration in C (Jonathan Blandford)
- try to enable gir generation. (Jonathan Blandford)
- the DELIM macros should be namespaced (Jonathan Blandford)
- Fix doc comments (Jonathan Blandford)
- s/IPuz/Ipuz/g (Jonathan Blandford)
